import { Dict } from "koishi";
export declare const enum ClientType {
    koishi = "koishi",
    nonebot = "nonebot"
}
export interface TelemetryEvent {
    name: string;
    localTime: number;
    localUTCTime: number;
    client: {
        type: ClientType;
        machineID: string;
        version: string;
        cpu: {
            arch: string;
            cpus: Array<{
                model: string;
                speed: number;
                times: {
                    user: number;
                    nice: number;
                    sys: number;
                    idle: number;
                    irq: number;
                };
            }>;
        };
        mem: {
            total: number;
            free: number;
        };
        system: {
            uptime: number;
            platform: string;
            release: string;
            type: string;
            versions: Dict<string, string>;
        };
    };
    data?: object;
}
export interface HeartbeatPackage extends TelemetryEvent {
    name: 'ping';
}
export interface OnlineEvent extends TelemetryEvent {
    name: 'online';
    data: {
        isReconnect?: boolean;
        reconnectTimes?: number;
        config: any;
    };
}
export interface OfflineEvent extends TelemetryEvent {
    name: 'offline';
    data: {
        config: any;
    };
}
export interface UseCommandEvent extends TelemetryEvent {
    name: 'command';
    data: {
        command: string;
        sessionContent: string;
        platform: string;
        timestamp: number;
        result?: string;
    };
}
export interface StreamingCommandEvent extends TelemetryEvent {
    name: 'streaming-command';
    data: UseCommandEvent['data'] & {
        parent: number;
    };
}
export interface ExceptionOrErrorEvent extends TelemetryEvent {
    name: 'exc';
    data: {
        command: string;
        sessionContent?: string;
        error: {
            stack?: string;
            message: string;
            name: string;
        };
        platform?: string;
        timestamp?: number;
    };
}
export interface FailedEvent extends TelemetryEvent {
    name: 'failed';
    data: {
        command: string;
        sessionContent: string;
        msg: string;
        platform: string;
        timestamp: number;
    };
}
export interface ServerResponse {
    code: number;
    message: string;
    data?: object;
}
export interface SuccessServerResp extends ServerResponse {
    code: 200;
    message: 'success';
    data?: any;
}
export interface ErrorServerResp extends ServerResponse {
    code: Exclude<number, 200>;
}
export interface CommandResponse extends SuccessServerResp {
    data: {
        cid: number;
    };
}
